from qeh.bb_calculator.bb_interpolator import interpolate_building_blocks
interpolate_building_blocks(BBfiles=['MoS2-bb', 'WSe2-bb'])
